@@ -37,7 +37,7 @@
 /* #undef CONDUIT_GIT_SHA1_ABBREV */
 /* #undef CONDUIT_GIT_TAG */
 
-#define CONDUIT_SYSTEM_TYPE "Linux-6.2.10-1-ARCH"
+#define CONDUIT_SYSTEM_TYPE "Linux-6.17.7-3-armv7-ARCH"
 
 #define CONDUIT_CPP_COMPILER "/usr/lib/distcc/bin/c++"
 
